@@ -80,11 +80,9 @@ where
     }
 
     #[inline(always)]
-    pub fn get_mut(&mut self, key: &K) -> Option<ValueMut<'_, V>> {
+    pub fn get_mut(&self, key: &K) -> Option<ValueMut<'_, V>> {
         let k = key.encode();
-        self.inner
-            .get(&k)
-            .map(|v| ValueMut::new(&mut self.inner, k, v))
+        self.inner.get(&k).map(|v| ValueMut::new(&self.inner, k, v))
     }
 
     #[inline(always)]
@@ -98,27 +96,27 @@ where
     }
 
     #[inline(always)]
-    pub fn insert(&mut self, key: K, value: V) -> Option<V> {
+    pub fn insert(&self, key: K, value: V) -> Option<V> {
         self.insert_ref(&key, &value)
     }
 
     #[inline(always)]
-    pub fn insert_ref(&mut self, key: &K, value: &V) -> Option<V> {
+    pub fn insert_ref(&self, key: &K, value: &V) -> Option<V> {
         self.inner.insert_ref(&key.encode(), value)
     }
 
     #[inline(always)]
-    pub fn set_value(&mut self, key: K, value: V) {
+    pub fn set_value(&self, key: K, value: V) {
         self.set_value_ref(&key, &value)
     }
 
     #[inline(always)]
-    pub fn set_value_ref(&mut self, key: &K, value: &V) {
+    pub fn set_value_ref(&self, key: &K, value: &V) {
         self.inner.set_value_ref(&key.encode(), value);
     }
 
     #[inline(always)]
-    pub fn entry(&mut self, key: K) -> Entry<'_, V> {
+    pub fn entry(&self, key: K) -> Entry<'_, V> {
         self.inner.entry(key.encode())
     }
 
@@ -136,17 +134,17 @@ where
     }
 
     #[inline(always)]
-    pub fn remove(&mut self, key: &K) -> Option<V> {
+    pub fn remove(&self, key: &K) -> Option<V> {
         self.inner.remove(&key.encode())
     }
 
     #[inline(always)]
-    pub fn unset_value(&mut self, key: &K) {
+    pub fn unset_value(&self, key: &K) {
         self.inner.unset_value(&key.encode());
     }
 
     #[inline(always)]
-    pub fn clear(&mut self) {
+    pub fn clear(&self) {
         self.inner.clear();
     }
 }
